@@ -18,7 +18,7 @@ from . import utils
 from .msg import common_debug, common_warn, common_err, common_error, common_info, warn_once
 
 
-_LOG_FILES = ("messages", "ha-log.txt", "ha-log", "cluster-log.txt", "journal.log", "pacemaker.log")
+_LOG_FILES = ("ha-log.txt", "messages", "ha-log", "cluster-log.txt", "journal.log", "pacemaker.log")
 
 
 #
@@ -50,6 +50,7 @@ def get_pe_num(pe_file):
         return m.group(1)
     return "-1"
 
+
 def pe_file_in_range(pe_f, a):
     if not a:
         return pe_f
@@ -638,17 +639,15 @@ class Report(object):
             self.report_setup()
             return self.ready
         else:
-            print("Refreshing log data...")
+            print "Refreshing log data..."
             if not self.ready:
                 self.set_change_origin(CH_TIME)
                 self.prepare_source()
             missing_pes = self.logparser.scan(mode='force')
             if len(missing_pes):
-                print("%d transitions, %d events and %d missing PE input files." %
-                      tuple(self.logparser.count() + (len(missing_pes),)))
+                print "%d transitions, %d events and %d missing PE input files." % tuple(self.logparser.count() + (len(missing_pes),))
             else:
-                print("%d transitions, %d events." %
-                      self.logparser.count())
+                print "%d transitions, %d events." % self.logparser.count()
 
     def _str_nodecolor(self, node, s):
         try:
@@ -1003,7 +1002,7 @@ class Report(object):
             utils.rmdir_r(session_dir)
         elif subcmd == "list":
             for l in self.session_list():
-                print(l)
+                print l
         elif subcmd == "pack":
             return mkarchive(session_dir)
         return True
