@@ -50,7 +50,7 @@ def _transition_start_re():
     3: pe file number
     """
     m1 = "crmd.*Processing graph ([0-9]+).*derived from (.*/pe-[^-]+-([0-9]+)[.]bz2)"
-    m2 = "pengine.*Transition ([0-9]+):.*([^ ]*/pe-[^-]+-([0-9]+)[.]bz2)"
+    m2 = "pengine.*[Tt]ransition ([0-9]+).*([^ ]*/pe-[^-]+-([0-9]+)[.]bz2)"
     try:
         return re.compile("(?:%s)|(?:%s)" % (m1, m2))
     except re.error, e:
@@ -242,7 +242,7 @@ class CibInfo(object):
         self.not_cloned_resources = set(x for x in self.primitives if x not in self.cloned_resources)
 
     def resources(self):
-        return self.primitives.keys() + self.groups.keys() + self.clones.keys()
+        return self.primitives + self.groups.keys() + self.clones.keys()
 
     def match_resources(self):
         """
