@@ -215,6 +215,8 @@ class BaseParser(object):
         """
         After a successful match, returns
         the groups generated by the match.
+
+        FIXME: check if _lastmatch is a list
         """
         return self._lastmatch.group(idx)
 
@@ -626,6 +628,59 @@ class BaseParser(object):
             else:
                 break
 
+    def match_op(self, out, pfx='op'):
+        """
+        op <optype> [<n>=<v> ...]
+
+        to:
+          <op name="monitor" timeout="30" interval="10" id="p_mysql-monitor-10">
+            <instance_attributes id="p_mysql-monitor-10-instance_attributes">
+              <nvpair name="depth" value="0" id="p_mysql-monitor-10-instance_attributes-depth"/>
+            </instance_attributes>
+          </op>
+        """
+        self.match('op')
+        op_type = self.match_identifier()
+        all_attrs = self.match_nvpairs(minpairs=0)
+        node = xmlutil.new('op', name=op_type)
+        if not any(nvp.get('name') == 'interval' for nvp in all_attrs):
+            all_attrs.append(xmlutil.nvpair('interval', '0'))
+        valid_attrs = validator.op_attributes()
+        inst_attrs = None
+        for nvp in all_attrs:
+            if nvp.get('name') in valid_attrs:
+                node.set(nvp.get('name'), nvp.get('value'))
+            else:
+                if inst_attrs is None:
+                    inst_attrs = xmlutil.child(node, 'instance_attributes')
+                inst_attrs.append(nvp)
+        out.append(node)
+
+    def match_operations(self, out, match_id):
+        from .cibconfig import cib_factory
+
+        def is_op():
+            return self.has_tokens() and self.current_token().lower() == 'op'
+        if match_id:
+            self.match('operations')
+        node = xmlutil.child(out, 'operations')
+        if match_id:
+            self.match_idspec()
+            match_id = self.matched(1)[1:].lower()
+            idval = self.matched(2)
+            if match_id == 'id-ref':
+                idval = cib_factory.resolve_id_ref('operations', idval)
+
+            node.set(match_id, idval)
+
+        # The ID assignment skips the operations node if possible,
+        # so we need to pass the prefix (id of the owner node)
+        # to match_op
+        pfx = out.get('id') or 'op'
+
+        while is_op():
+            self.match_op(node, pfx=pfx)
+
 
 _parsers = {}
 
@@ -686,59 +741,6 @@ class ResourceParser(BaseParser):
         xmlutil.maybe_set(out, 'provider', cpt[1])
         xmlutil.maybe_set(out, 'type', cpt[2])
 
-    def match_op(self, out, pfx='op'):
-        """
-        op <optype> [<n>=<v> ...]
-
-        to:
-          <op name="monitor" timeout="30" interval="10" id="p_mysql-monitor-10">
-            <instance_attributes id="p_mysql-monitor-10-instance_attributes">
-              <nvpair name="depth" value="0" id="p_mysql-monitor-10-instance_attributes-depth"/>
-            </instance_attributes>
-          </op>
-        """
-        self.match('op')
-        op_type = self.match_identifier()
-        all_attrs = self.match_nvpairs(minpairs=0)
-        node = xmlutil.new('op', name=op_type)
-        if not any(nvp.get('name') == 'interval' for nvp in all_attrs):
-            all_attrs.append(xmlutil.nvpair('interval', '0'))
-        valid_attrs = validator.op_attributes()
-        inst_attrs = None
-        for nvp in all_attrs:
-            if nvp.get('name') in valid_attrs:
-                node.set(nvp.get('name'), nvp.get('value'))
-            else:
-                if inst_attrs is None:
-                    inst_attrs = xmlutil.child(node, 'instance_attributes')
-                inst_attrs.append(nvp)
-        out.append(node)
-
-    def match_operations(self, out, match_id):
-        from .cibconfig import cib_factory
-
-        def is_op():
-            return self.has_tokens() and self.current_token().lower() == 'op'
-        if match_id:
-            self.match('operations')
-        node = xmlutil.child(out, 'operations')
-        if match_id:
-            self.match_idspec()
-            match_id = self.matched(1)[1:].lower()
-            idval = self.matched(2)
-            if match_id == 'id-ref':
-                idval = cib_factory.resolve_id_ref('operations', idval)
-
-            node.set(match_id, idval)
-
-        # The ID assignment skips the operations node if possible,
-        # so we need to pass the prefix (id of the owner node)
-        # to match_op
-        pfx = out.get('id') or 'op'
-
-        while is_op():
-            self.match_op(node, pfx=pfx)
-
     def parse(self, cmd):
         return self.begin_dispatch(cmd, min_args=2)
 
@@ -1039,7 +1041,7 @@ def property_parser(self, cmd):
 class FencingOrderParser(BaseParser):
     """
     <fencing-topology>
-    <fencing-level id=<id> target=<text> index=<+int> devices="\w,\w..."/>
+    <fencing-level id=<id> target=<text> index=<+int> devices=r"\w,\w..."/>
     </fencing-topology>
 
     new:
@@ -1050,7 +1052,7 @@ class FencingOrderParser(BaseParser):
 
     <fencing-topology>
     <fencing-level id=<id> target-attribute=<text> target-value=<text>
-                   index=<+int> devices="\w,\w..."/>
+                   index=<+int> devices=r"\w,\w..."/>
     </fencing-topology>
 
     from 1.1.14 on, target can be a regexp pattern:
@@ -1059,7 +1061,7 @@ class FencingOrderParser(BaseParser):
 
     <fencing-topology>
     <fencing-level id=<id> target-pattern=<pattern>
-                   index=<+int> devices="\w,\w..."/>
+                   index=<+int> devices=r"\w,\w..."/>
     </fencing-topology>
 
     fencing-topology \
@@ -1068,7 +1070,7 @@ class FencingOrderParser(BaseParser):
 
     """
     def parse(self, cmd):
-        self.begin(cmd, min_args=1)
+        self.begin(cmd)
         if not self.try_match("fencing-topology"):
             self.match("fencing_topology")
         target = "@@"
@@ -1083,15 +1085,17 @@ class FencingOrderParser(BaseParser):
                 target = self.matched(1)
             else:
                 raw_levels.append((target, self.match_any()))
-        if len(raw_levels) == 0:
-            self.err("Missing list of devices")
         return self._postprocess_levels(raw_levels)
 
     def _postprocess_levels(self, raw_levels):
         from collections import defaultdict
         from itertools import repeat
         from .cibconfig import cib_factory
-        if raw_levels[0][0] == "@@":
+        if len(raw_levels) == 0:
+            def no_levels():
+                return []
+            lvl_generator = no_levels
+        elif raw_levels[0][0] == "@@":
             def node_levels():
                 for node in cib_factory.node_id_list():
                     for target, devices in raw_levels:
@@ -1373,9 +1377,9 @@ def parse_xml(self, cmd):
     # they produce text elements
     try:
         e = etree.fromstring(xml_data)
-    except Exception, e:
+    except Exception as err:
         common_err("Cannot parse XML data: %s" % xml_data)
-        self.err(e)
+        self.err(err)
     if e.tag not in constants.cib_cli_map:
         self.err("Element %s not recognized" % (e.tag))
     return e
