@@ -70,7 +70,7 @@ def ra_classes_or_tmpl(args):
 
 
 def op_attr_list(args):
-    schema_attr = [schema.g_schema.get('attr', 'op', 'o') + '=']
+    schema_attr = [schema.get('attr', 'op', 'o') + '=']
     extra_attrs = [s + '=' for s in constants.op_extra_attrs]
     return schema_attr + extra_attrs
 
@@ -174,7 +174,7 @@ def _prim_op_completer(agent, args):
     if completing == 'op':
         return ['op']
     if args[-2] == 'op':
-        return constants.op_cli_names
+        return list(constants.op_cli_names)
 
     return []
 
@@ -272,7 +272,7 @@ class CibConfig(command.UI):
     @command.skill_level('administrator')
     def do_keywords(self, context):
         for k, v in sorted(constants.keywords.iteritems(), key=lambda v: v[0].lower()):
-            print("%-16s %s" % (k, v))
+            print "%-16s %s" % (k, v)
 
     @command.level(ui_ra.RA)
     def do_ra(self):
@@ -446,7 +446,6 @@ class CibConfig(command.UI):
         from . import ra
         from . import cibconfig
         from . import cliformat
-        from . import msg as msglog
         obj = cib_factory.find_object(rsc)
         if not obj:
             context.error("Not found: %s" % (rsc))
@@ -454,7 +453,7 @@ class CibConfig(command.UI):
             context.error("Not a primitive: %s" % (rsc))
         rnode = cibconfig.reduce_primitive(obj.node)
         if rnode is None:
-            context.error("No resource template %s for %s" % (self.node.get("template"), rsc))
+            context.error("No resource template %s for %s" % (obj.node.get("template"), rsc))
         params = []
         for attrs in rnode.iterchildren("instance_attributes"):
             params.extend(cliformat.nvpairs2list(attrs))
@@ -464,18 +463,7 @@ class CibConfig(command.UI):
         agentname = xmlutil.mk_rsc_type(rnode)
         if not ra.can_validate_agent(agentname):
             context.error("%s: Cannot run validate-all for agent: %s" % (rsc, agentname))
-        rc, out = ra.validate_agent(agentname, params)
-        for msg in out.splitlines():
-            if msg.startswith("ERROR: "):
-                msglog.err_buf.error(msg[7:])
-            elif msg.startswith("WARNING: "):
-                msglog.err_buf.warning(msg[9:])
-            elif msg.startswith("INFO: "):
-                msglog.err_buf.info(msg[6:])
-            elif msg.startswith("DEBUG: "):
-                msglog.err_buf.debug(msg[7:])
-            else:
-                msglog.err_buf.writemsg(msg)
+        rc, _ = ra.validate_agent(agentname, params, log=True)
         return rc == 0
 
     @command.skill_level('administrator')
@@ -526,19 +514,10 @@ class CibConfig(command.UI):
         "usage: graph [<gtype> [<file> [<img_format>]]]"
         if args and args[0] == "exportsettings":
             return utils.save_graphviz_file(userdir.GRAPHVIZ_USER_FILE, constants.graph)
-        rc, gtype, outf, ftype = ui_utils.graph_args(args)
-        if not rc:
-            context.fatal_error("Failed to create graph")
-        rc, d = utils.load_graphviz_file(userdir.GRAPHVIZ_USER_FILE)
-        if rc and d:
-            constants.graph = d
         set_obj = mkset_obj()
-        if not outf:
-            rc = set_obj.show_graph(gtype)
-        elif gtype == ftype:
-            rc = set_obj.save_graph(gtype, outf)
-        else:
-            rc = set_obj.graph_img(gtype, outf, ftype)
+        rc = set_obj.query_graph(*args)
+        if rc is None:
+            context.fatal_error("Failed to create graph")
         return rc
 
     def _stop_if_running(self, rscs):
@@ -560,7 +539,7 @@ class CibConfig(command.UI):
         "usage: delete [-f|--force] <id> [<id>...]"
         argl = list(args)
         arg_force = any((x in ('-f', '--force')) for x in argl)
-        argl = [x for x in argl if (x not in ('-f', '--force'))]
+        argl = [x for x in argl if x not in ('-f', '--force')]
         if arg_force or config.core.force:
             if self._stop_if_running(argl) > 0:
                 utils.wait4dc(what="Stopping %s" % (", ".join(argl)))
