@@ -12,9 +12,7 @@ from . import command
 from . import completers as compl
 from . import utils
 from . import ui_utils
-from . import userdir
 from . import xmlutil
-from . import constants
 from . import options
 from .cibconfig import mkset_obj, cib_factory
 from .msg import common_err, common_debug, common_info
@@ -338,7 +336,7 @@ class History(command.UI):
             tags = crm_report().get_transition_tags(f)
             rc = tags is not None
             if rc:
-                print(' '.join(tags) if len(tags) else "No tags.")
+                print ' '.join(tags) if len(tags) else "No tags."
         else:
             rc = crm_report().show_transition_log(f, True)
         return rc
@@ -434,53 +432,36 @@ class History(command.UI):
         self._reset_cib_env()
         return s
 
-    def _worddiff(self, s1, s2):
-        s = None
-        f1 = utils.str2tmp(s1)
-        f2 = utils.str2tmp(s2)
-        if f1 and f2:
-            _, s = utils.get_stdout("wdiff %s %s" % (f1, f2))
-        for f in (f1, f2):
-            try:
-                os.unlink(f)
-            except:
-                pass
-        return s
-
-    def _unidiff(self, s1, s2, t1, t2):
-        s = None
-        f1 = utils.str2tmp(s1)
-        f2 = utils.str2tmp(s2)
-        if f1 and f2:
-            _, s = utils.get_stdout("diff -U 0 -d -b --label %s --label %s %s %s" %
-                                     (t1, t2, f1, f2))
-
-        for f in (f1, f2):
-            try:
-                os.unlink(f)
-            except:
-                pass
-        return s
-
-    def _diffhtml(self, s1, s2, t1, t2):
-        import difflib
-        fromlines = s1.split('\n')
-        tolines = s2.split('\n')
-        diff_l = difflib.HtmlDiff(wrapcolumn=60).make_table(
-            fromlines, tolines, t1, t2)
-        return ''.join(diff_l)
-
     def _diff(self, pe_fun, t1, t2, html=False, wdiff=False):
+        def _diff_impl(s1, s2, cmd):
+            s = None
+            f1 = utils.str2tmp(s1)
+            f2 = utils.str2tmp(s2)
+            try:
+                if f1 and f2:
+                    _, s = utils.get_stdout(cmd.format(f1=f1, f2=f2))
+            finally:
+                for f in (f1, f2):
+                    try:
+                        os.unlink(f)
+                    except os.error:
+                        pass
+            return s
+
+        def _diffhtml(s1, s2, t1, t2):
+            import difflib
+            return ''.join(difflib.HtmlDiff(tabsize=2, wrapcolumn=120).make_table(s1.split('\n'), s2.split('\n'), t1, t2)).replace('&nbsp;&nbsp;', '&nbsp;')
+
         s1 = self._render_pe(pe_fun, t1)
         s2 = self._render_pe(pe_fun, t2)
         if not s1 or not s2:
             return None
         if html:
-            s = self._diffhtml(s1, s2, t1, t2)
+            s = _diffhtml(s1, s2, t1, t2)
         elif wdiff:
-            s = self._worddiff(s1, s2)
+            s = _diff_impl(s1, s2, "wdiff {f1} {f2}")
         else:
-            s = self._unidiff(s1, s2, t1, t2)
+            s = _diff_impl(s1, s2, "diff -U 0 -d -b --label %s --label %s {f1} {f2}" % (t1, t2))
         return s
 
     def _common_pe_render_check(self, context, opt_l, *args):
@@ -548,19 +529,10 @@ class History(command.UI):
         pe_f = self._get_diff_pe_input(t)
         if not pe_f:
             return False
-        rc, gtype, outf, ftype = ui_utils.graph_args(args)
-        if not rc:
-            return False
-        rc, d = utils.load_graphviz_file(userdir.GRAPHVIZ_USER_FILE)
-        if rc and d:
-            constants.graph = d
         set_obj = self._pe_config_obj(pe_f)
-        if not outf:
-            rc = set_obj.show_graph(gtype)
-        elif gtype == ftype:
-            rc = set_obj.save_graph(gtype, outf)
-        else:
-            rc = set_obj.graph_img(gtype, outf, ftype)
+        rc = set_obj.query_graph(*args)
+        if rc is None:
+            return False
         if context.previous_level_is("cibconfig"):
             cib_factory.refresh()
         return rc
