@@ -50,7 +50,7 @@ class ConsolePrinter(object):
         else:
             err_buf.error("%s (rc=%s)" % (action['shortdesc'] or action['name'], rc))
         if output:
-            print(output)
+            print output
 
     def flush(self):
         if self.in_progress:
@@ -96,7 +96,7 @@ class JsonPrinter(object):
             ret['error'] = str(output) if output else ''
         else:
             ret['output'] = str(output) if output else ''
-        print(json.dumps(ret))
+        print json.dumps(ret)
 
     def flush(self):
         pass
@@ -194,8 +194,8 @@ class Script(command.UI):
         for arg in args:
             if arg.lower() not in ("all", "names"):
                 context.fatal_error("Unexpected argument '%s': expected  [all|names]" % (arg))
-        show_all = any([x for x in args if x.lower() == 'all'])
-        names = any([x for x in args if x.lower() == 'names'])
+        show_all = any(x.lower() == 'all' for x in args)
+        names = any(x.lower() == 'names' for x in args)
         if not names:
             categories = {}
             for name in scripts.list_scripts():
@@ -215,23 +215,23 @@ class Script(command.UI):
                     continue
             for c, lst in sorted(categories.iteritems(), key=lambda x: x[0]):
                 if c:
-                    print("%s:\n" % (c))
+                    print "%s:\n" % (c)
                 for s in sorted(lst):
-                    print(s)
-                print('')
+                    print s
+                print ''
         elif show_all:
             for name in scripts.list_scripts():
-                print(name)
+                print name
         else:
             for name in scripts.list_scripts():
                 try:
                     script = scripts.load_script(name)
-                    if script is None or script['category'] == 'script':
+                    if script is None or script['category'].lower() == 'script':
                         continue
                 except ValueError as err:
                     err_buf.error(str(err))
                     continue
-                print(name)
+                print name
 
     @command.completers_repeating(compl.call(scripts.list_scripts))
     @command.alias('info', 'describe')
@@ -279,20 +279,20 @@ class Script(command.UI):
         if ret is None:
             return False
         if not ret:
-            print("OK (no actions)")
+            print "OK (no actions)"
         for i, action in enumerate(ret):
             shortdesc = action.get('shortdesc', '')
             text = str(action.get('text', ''))
             longdesc = str(action.get('longdesc', ''))
-            print("%s. %s\n" % (i + 1, shortdesc))
+            print "%s. %s\n" % (i + 1, shortdesc)
             if longdesc:
                 for line in str(longdesc).split('\n'):
-                    print("\t%s" % (line))
-                print('')
+                    print "\t%s" % (line)
+                print ''
             if text:
                 for line in str(text).split('\n'):
-                    print("\t%s" % (line))
-                print('')
+                    print "\t%s" % (line)
+                print ''
 
     @command.completers(compl.call(scripts.list_scripts))
     def do_run(self, context, name, *args):
@@ -393,10 +393,10 @@ class Script(command.UI):
             tgtfile = os.path.join(tgtdir, name, "main.yml")
             with open(tgtfile, 'w') as tf:
                 try:
-                    print("%s -> %s" % (fromscript, tgtfile))
+                    print "%s -> %s" % (fromscript, tgtfile)
                     yaml.dump([script], tf, explicit_start=True, default_flow_style=False)
                 except Exception as err:
-                    print(err)
+                    print err
 
     def _json_list(self, context, cmd):
         """
@@ -406,13 +406,13 @@ class Script(command.UI):
             try:
                 script = scripts.load_script(name)
                 if script is not None:
-                    print(json.dumps({'name': name,
+                    print json.dumps({'name': name,
                                       'category': script['category'].lower(),
                                       'shortdesc': script['shortdesc'],
-                                      'longdesc': scripts.format_desc(script['longdesc'])}))
+                                      'longdesc': scripts.format_desc(script['longdesc'])})
             except ValueError as err:
-                print(json.dumps({'name': name,
-                                  'error': str(err)}))
+                print json.dumps({'name': name,
+                                  'error': str(err)})
         return True
 
     def _json_show(self, context, cmd):
@@ -420,17 +420,17 @@ class Script(command.UI):
         ["show", <name>]
         """
         if len(cmd) < 2:
-            print(json.dumps({'error': 'Incorrect number of arguments: %s (expected %s)' % (len(cmd), 2)}))
+            print json.dumps({'error': 'Incorrect number of arguments: %s (expected %s)' % (len(cmd), 2)})
             return False
         name = cmd[1]
         script = scripts.load_script(name)
         if script is None:
             return False
-        print(json.dumps({'name': script['name'],
+        print json.dumps({'name': script['name'],
                           'category': script['category'].lower(),
                           'shortdesc': script['shortdesc'],
                           'longdesc': scripts.format_desc(script['longdesc']),
-                          'steps': scripts.clean_steps(script['steps'])}))
+                          'steps': scripts.clean_steps(script['steps'])})
         return True
 
     def _json_verify(self, context, cmd):
@@ -438,7 +438,7 @@ class Script(command.UI):
         ["verify", <name>, <params>]
         """
         if len(cmd) < 3:
-            print(json.dumps({'error': 'Incorrect number of arguments: %s (expected %s)' % (len(cmd), 3)}))
+            print json.dumps({'error': 'Incorrect number of arguments: %s (expected %s)' % (len(cmd), 3)})
             return False
         name = cmd[1]
         params = cmd[2]
@@ -457,7 +457,7 @@ class Script(command.UI):
                        'nodes': str(action.get('nodes', ''))}
                 if 'sudo' in action:
                     obj['sudo'] = action['sudo']
-                print(json.dumps(obj))
+                print json.dumps(obj)
         return True
 
     def _json_run(self, context, cmd):
@@ -465,7 +465,7 @@ class Script(command.UI):
         ["run", <name>, <params>]
         """
         if len(cmd) < 3:
-            print(json.dumps({'error': 'Incorrect number of arguments: %s (expected %s)' % (len(cmd), 3)}))
+            print json.dumps({'error': 'Incorrect number of arguments: %s (expected %s)' % (len(cmd), 3)})
             return False
         name = cmd[1]
         params = cmd[2]
@@ -479,7 +479,7 @@ class Script(command.UI):
         if not ret and printer.results:
             for result in printer.results:
                 if 'error' in result:
-                    print(json.dumps(result))
+                    print json.dumps(result)
         return ret
 
     def do_json(self, context, command):
@@ -504,7 +504,7 @@ class Script(command.UI):
         """
         cmd = json.loads(command)
         if len(cmd) < 1:
-            print(json.dumps({'error': 'Failed to decode valid JSON command'}))
+            print json.dumps({'error': 'Failed to decode valid JSON command'})
             return False
         try:
             if cmd[0] == "list":
@@ -516,8 +516,8 @@ class Script(command.UI):
             elif cmd[0] == "run":
                 return self._json_run(context, cmd)
             else:
-                print(json.dumps({'error': "Unknown command: %s" % (cmd[0])}))
+                print json.dumps({'error': "Unknown command: %s" % (cmd[0])})
                 return False
         except ValueError, err:
-            print(json.dumps({'error': str(err)}))
+            print json.dumps({'error': str(err)})
             return False
