@@ -10,6 +10,7 @@ import glob
 import time
 import datetime
 import shutil
+import shlex
 import bz2
 import fnmatch
 import gc
@@ -25,6 +26,7 @@ from .msg import common_warn, common_info, common_debug, common_err, err_buf
 def memoize(function):
     "Decorator to invoke a function once only for any argument"
     memoized = {}
+
     def inner(*args):
         if args in memoized:
             return memoized[args]
@@ -53,6 +55,32 @@ def this_node():
     return os.uname()[1]
 
 
+def network_defaults(interface=None):
+    """
+    returns (interface, ip-address, network, prefix-length)
+    """
+    def valfor(l, key):
+        for i in range(0, len(l) - 1):
+            if l[i] == key:
+                return l[i + 1]
+        return None
+    _, outp = get_stdout("/sbin/ip -o route show")
+    info = [None, None, None, None]
+    if interface is not None:
+        info[0] = interface
+    for l in outp.splitlines():
+        sp = l.split()
+        if info[0] is None and len(sp) >= 5 and sp[0] == 'default' and sp[1] == 'via':
+            info[0] = sp[4]
+        if info[0] is not None:
+            if sp[0].find('/') >= 0 and valfor(sp, 'dev') == info[0]:
+                nw, length = sp[0].split('/')
+                info[1], info[2], info[3] = valfor(sp, 'src'), nw, length
+    if info[0] is None:
+        raise ValueError("Failed to determine default network interface")
+    return tuple(info)
+
+
 _cib_shadow = 'CIB_shadow'
 _cib_in_use = ''
 
@@ -245,6 +273,20 @@ def add_sudo(cmd):
     return cmd
 
 
+def chown(path, user, group):
+    if isinstance(user, int):
+        uid = user
+    else:
+        import pwd
+        uid = pwd.getpwnam(user).pw_uid
+    if isinstance(group, int):
+        gid = group
+    else:
+        import grp
+        gid = grp.getgrnam(group).gr_gid
+    os.chown(path, uid, gid)
+
+
 def ensure_sudo_readable(f):
     # make sure the tempfile is readable to crm_diff (bsc#999683)
     if config.core.user:
@@ -327,17 +369,77 @@ def str2tmp(s, suffix=".pcmk"):
     return tmp
 
 
+@contextmanager
+def create_tempfile(suffix='', dir=None):
+    """ Context for temporary file.
+
+    Will find a free temporary filename upon entering
+    and will try to delete the file on leaving, even in case of an exception.
+
+    Parameters
+    ----------
+    suffix : string
+        optional file suffix
+    dir : string
+        optional directory to save temporary file in
+
+    (from http://stackoverflow.com/a/29491523)
+    """
+    import tempfile
+    tf = tempfile.NamedTemporaryFile(delete=False, suffix=suffix, dir=dir)
+    tf.file.close()
+    try:
+        yield tf.name
+    finally:
+        try:
+            os.remove(tf.name)
+        except OSError as e:
+            if e.errno == 2:
+                pass
+            else:
+                raise
+
+
+@contextmanager
+def open_atomic(filepath, mode="r", buffering=-1, fsync=False):
+    """ Open temporary file object that atomically moves to destination upon
+    exiting.
+
+    Allows reading and writing to and from the same filename.
+
+    The file will not be moved to destination in case of an exception.
+
+    Parameters
+    ----------
+    filepath : string
+        the file path to be opened
+    fsync : bool
+        whether to force write the file to disk
+
+    (from http://stackoverflow.com/a/29491523)
+    """
+
+    with create_tempfile(dir=os.path.dirname(os.path.abspath(filepath))) as tmppath:
+        with open(tmppath, mode, buffering) as file:
+            try:
+                yield file
+            finally:
+                if fsync:
+                    file.flush()
+                    os.fsync(file.fileno())
+        os.rename(tmppath, filepath)
+
+
 def str2file(s, fname):
     '''
     Write a string to a file.
     '''
     try:
-        f = open(fname, "w")
+        with open_atomic(fname, 'w') as dst:
+            dst.write(s)
     except IOError, msg:
         common_err(msg)
         return False
-    f.write(s)
-    f.close()
     return True
 
 
@@ -509,7 +611,7 @@ def lock(lockdir):
                 return True
             except OSError, (errno, strerror):
                 if errno != os.errno.EEXIST:
-                    common_err("Failed to acquire lock to %s: %s" %(lockdir, strerror))
+                    common_err("Failed to acquire lock to %s: %s" % (lockdir, strerror))
                     return False
                 time.sleep(0.1)
                 continue
@@ -524,6 +626,12 @@ def lock(lockdir):
             rmdir_r(os.path.join(lockdir, _LOCKDIR))
 
 
+def mkdirp(d, mode=0777):
+    if os.path.isdir(d):
+        return True
+    os.makedirs(d, mode=mode)
+
+
 def pipe_cmd_nosudo(cmd):
     if options.regression_tests:
         print ".EXT", cmd
@@ -639,7 +747,7 @@ def wait4dc(what="", show_progress=True):
     delay = get_stdout(add_sudo(cmd))[1]
     if delay:
         delaymsec = crm_msec(delay)
-        if 0 < delaymsec:
+        if delaymsec > 0:
             common_info("The crmd-transition-delay is configured. Waiting %d msec before check DC status." % delaymsec)
             time.sleep(delaymsec / 1000)
     cnt = 0
@@ -811,8 +919,8 @@ def sort_by_mtime(l):
 
 def file_find_by_name(root, filename):
     'Find a file within a tree matching fname'
-    assert(root)
-    assert(filename)
+    assert root
+    assert filename
     for root, dirnames, filenames in os.walk(root):
         for filename in fnmatch.filter(filenames, filename):
             return os.path.join(root, filename)
@@ -844,14 +952,25 @@ def is_int(s):
 
 
 def is_process(s):
-    cmd = "ps -e -o pid,command | grep -qs '%s'" % s
-    if options.regression_tests:
-        print ".EXT", cmd
-    proc = subprocess.Popen(cmd,
-                            shell=True,
-                            stdout=subprocess.PIPE)
-    proc.wait()
-    return proc.returncode == 0
+    """
+    Returns true if argument is the name of a running process.
+
+    s: process name
+    returns Boolean
+    """
+    from os.path import join, basename
+    # find pids of running processes
+    pids = [pid for pid in os.listdir('/proc') if pid.isdigit()]
+    for pid in pids:
+        try:
+            cmdline = open(join('/proc', pid, 'cmdline'), 'rb').read()
+            procname = basename(cmdline.replace('\x00', ' ').split(' ')[0])
+            if procname == s:
+                return True
+        except os.error:
+            # a process may have died since we got the list of pids
+            pass
+    return False
 
 
 def print_stacktrace():
@@ -962,6 +1081,7 @@ def page_gen(g):
     else:
         pipe_string(get_pager_cmd(), term_render("".join(g)))
 
+
 def page_file(filename):
     'Open file in pager'
     if not os.path.isfile(filename):
@@ -1023,9 +1143,9 @@ def find_value(pl, name):
 
 
 def cli_replace_attr(pl, name, new_val):
-    for i in range(len(pl)):
-        if pl[i][0] == name:
-            pl[i][1] = new_val
+    for i, attr in enumerate(pl):
+        if attr[0] == name:
+            attr[1] = new_val
             return
 
 
@@ -1360,6 +1480,17 @@ def quote(s):
     return "'" + s.replace("'", "'\"'\"'") + "'"
 
 
+def doublequote(s):
+    """Return a shell-escaped version of the string *s*."""
+    if not s:
+        return '""'
+    if _find_unsafe(s) is None:
+        return s
+
+    # use double quotes
+    return '"' + s.replace('"', "\\\"") + '"'
+
+
 def fetch_opts(args, opt_l):
     '''
     Get and remove option keywords from args.
@@ -1515,6 +1646,61 @@ def noquotes(v):
     return _NOQUOTES_RE.match(v) is not None
 
 
+def unquote(s):
+    """
+    Reverse shell-quoting a string, so the string '"a b c"'
+    becomes 'a b c'
+    """
+    sp = shlex.split(s)
+    if len(sp) > 0:
+        return sp[0]
+    return ""
+
+
+def parse_sysconfig(sysconfig_file):
+    """
+    Reads a sysconfig file into a dict
+    """
+    ret = {}
+    vre = re.compile(r"(\S+)\s*=\s*(.*)")
+    if os.path.isfile(sysconfig_file):
+        for line in open(sysconfig_file).readlines():
+            if line.lstrip().startswith('#'):
+                continue
+            m = vre.match(line)
+            if m:
+                ret[m.group(1)] = unquote(m.group(2))
+    return ret
+
+
+def sysconfig_set(sysconfig_file, **values):
+    """
+    Set the values in the sysconfig file, updating the variables
+    if they exist already, appending them if not.
+    """
+    vre = re.compile(r"(\S+)\s*=\s*(.*)")
+    outp = ""
+    if os.path.isfile(sysconfig_file):
+        for line in open(sysconfig_file).readlines():
+            if line.lstrip().startswith('#'):
+                outp += line
+            else:
+                matched = False
+                m = vre.match(line)
+                if m:
+                    for k, v in values.iteritems():
+                        if k == m.group(1):
+                            matched = True
+                            outp += '%s=%s\n' % (k, doublequote(v))
+                            del values[k]
+                            break
+                if not matched:
+                    outp += line
+    for k, v in values.iteritems():
+        outp += '%s=%s\n' % (k, doublequote(v))
+    str2file(outp, sysconfig_file)
+
+
 def remote_diff_slurp(nodes, filename):
     try:
         import parallax
@@ -1611,6 +1797,7 @@ def cluster_copy_file(local_path, nodes=None):
 # should be obscured as a sequence of **** when printed
 _obscured_nvpairs = []
 
+
 def obscured(key, value):
     if key is not None and value is not None:
         for o in _obscured_nvpairs:
@@ -1618,6 +1805,7 @@ def obscured(key, value):
                 return '*' * 6
     return value
 
+
 @contextmanager
 def obscure(obscure_list):
     global _obscured_nvpairs
@@ -1629,5 +1817,4 @@ def obscure(obscure_list):
         _obscured_nvpairs = prev
 
 
-
 # vim:ts=4:sw=4:et:
